DirtyLine

Struct DirtyLine 

pub struct DirtyLine(/* private fields */);
A codec working with JSONRPC 2.0 messages on top of badly encoded utf-8.

This works like the Line codec. However, it can cope with the input not being valid utf-8. That is arguably broken, nevertheless found in the wild and sometimes the only thing left to be done is to cope with it. This copes with it by running the input through the String::from_utf8_lossy conversion, effectively replacing anything that is not valid with these special utf-8 WTF question marks (U+FFFD).

In contrast, Line errors on such invalid inputs. Encoding is the same for both codecs, however.

Implementations

Source

impl DirtyLine

pub fn new() -> Self

A constructor