AbstractServer

Struct AbstractServer 

pub struct AbstractServer<S: Server>(/* private fields */);
An RPC server wrapper with dynamic dispatch.

This server wraps another server and converts it into a common ground, so multiple different servers can be used as trait objects. Basically, it boxes the futures it returns and converts the result into serde_json::Value. It can then be used together with ServerChain easilly. Note that this conversion incurs runtime costs.

Implementations

Source

impl<S: Server> AbstractServer<S>

pub fn new(server: S) -> Self

Wraps another server into an abstract server.

pub fn into_inner(self) -> S

Unwraps the abstract server and provides the one inside back.