pub struct AbstractServer<S: Server>(/* private fields */);Expand description
An RPC server wrapper with dynamic dispatch.
This server wraps another server and converts it into a common ground, so multiple different
servers can be used as trait objects. Basically, it boxes the futures it returns and converts
the result into serde_json::Value. It can then be used together with
ServerChain easilly. Note that this conversion incurs
runtime costs.
Implementations
Sourceimpl<S: Server> AbstractServer<S>
impl<S: Server> AbstractServer<S>
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Unwraps the abstract server and provides the one inside back.