pub struct ServerChain(/* private fields */);Expand description
A server that chains several other servers.
This composes multiple servers into one. When a notification or an rpc comes, it tries one by one and passes the call to each of them. If the server provides an answer, the iteration is stopped and that answer is returned. If the server refuses the given method name, another server in the chain is tried, until one is found or we run out of servers.
Initialization is called on all the servers.
The AbstractServer is one of the ways to plug servers with
incompatible future and success types inside.
Implementations